.. _todo:

TODO
=====

[X] create debian package

[X] create documentation

[X] calculate retransmission times for DISCOVER

[ ] (WIP) create tests

[ ] (WIP) integrate with Network Manager

[ ] listen in several interfaces

[ ] create systemd service

[ ] create init.d daemon

[ ] limit privileges

[ ] include MAC anonymization module

[ ] create apparmor profile

[ ] implement IPv6
